'* Library:       WebSphere MQ
'* Component:     MQ.NET Sample Programs
'* Part:          VMQSPUT.VB
'*
'* Description:   Sample Visual Basic program that puts messages to a named
'*                queue.
'*
'*                VMQSPUT has 3 parameters:
'*                - the name of a queue (required)
'*                - the name of a queue manager (optional)
'*                - the definition of a channel (optional)
'*
'*                If no queue manager name is given, the queue manager
'*                defaults to the default local queue manager. If a
'*                channel is defined, it should have the same format
'*                as the MQSERVER environment variable.
'*  <START_COPYRIGHT> 
'*  Licensed Materials - Property of IBM 
'*                   
'*  5724-B41         
'*  (C) Copyright IBM Corp. 1994, 2003 All Rights Reserved. 
'*                   
'*  US Government Users Restricted Rights - Use, duplication or 
'*  disclosure restricted by GSA ADP Schedule Contract with 
'*  IBM Corp.        
'*  <END_COPYRIGHT>

Imports System
Imports IBM.WMQ

Module vmqsput

    Function Main(ByVal CmdArgs() As String) As Integer

        Dim mqQMgr As MQQueueManager            '* MQQueueManager instance
        Dim mqQueue As MQQueue                  '* MQQueue instance
        Dim mqMsg As MQMessage                  '* MQMessage instance
        Dim mqPutMsgOpts As MQPutMessageOptions '* MQPutMessageOptions instance
        Dim queueName As String                 '* Name of queue to use
        Dim msgLen As Integer                   '* Message length
        Dim message As String                   '* Message buffer

        System.Console.WriteLine("Sample VMQSPUT start")
        If (CmdArgs.Length = 0) Then
            System.Console.WriteLine("Required parameter missing - queue name")
            Return (99)
        Else
            queueName = CmdArgs.GetValue(0)
        End If

        '*
        '* Try to create an MQQueueManager instance 
        '* 
        Try
            If (CmdArgs.Length > 2) Then
                '* queue name, queue manager name, channel definition all provided

                '* Break down the channel definition,
                '* which is of the form "channel-name/transport-type/connection-name".
                Dim channelDefinition As String = CmdArgs.GetValue(2)
                Dim channelName As String
                Dim transportType As String
                Dim connectionName As String
                Dim separator As Char() = "/"
                Dim parts As String()

                parts = channelDefinition.Split(separator)
                If (parts.Length > 0) Then
                    channelName = parts(0)
                End If
                If (parts.Length > 1) Then
                    transportType = parts(1)
                End If
                If (parts.Length > 2) Then
                    connectionName = parts(2)
                End If
                mqQMgr = New MQQueueManager(CmdArgs.GetValue(1), channelName, connectionName)
            Else
                If (CmdArgs.Length = 2) Then
                    '* queue name, queue manager name provided
                    mqQMgr = New MQQueueManager(CmdArgs.GetValue(1))
                Else
                    '* queue name provided - use default queue manager
                    mqQMgr = New MQQueueManager()
                End If
            End If
        Catch mqe As IBM.WMQ.MQException
            '* stop if failed
            System.Console.WriteLine("create of MQQueueManager ended with {0}", mqe.Message)
            Return (mqe.Reason)
        End Try


        '*
        '* Try to open the queue
        '*
        Try
            mqQueue = mqQMgr.AccessQueue(queueName, MQC.MQOO_OUTPUT + MQC.MQOO_FAIL_IF_QUIESCING)     '* open queue for output but not if MQM stopping
        Catch mqe As IBM.WMQ.MQException
            '* stop if failed
            System.Console.WriteLine("MQQueueManager::AccessQueue ended with {0}", mqe.Message)
            Return (mqe.Reason)
        End Try

        '*
        '* Read lines from the console and put them to the message queue
        '* Loop until end of input, or there is a failure
        '* 
        Dim isContinue As Boolean = True
        Do While (isContinue = True)
            message = System.Console.ReadLine()
            msgLen = message.Length

            If (msgLen > 0) Then
                '* put the next message to the queue
                mqMsg = New MQMessage()
                mqMsg.WriteString(message)
                mqMsg.Format = MQC.MQFMT_STRING
                mqPutMsgOpts = New MQPutMessageOptions()
                Try
                    mqQueue.Put(mqMsg, mqPutMsgOpts)
                Catch mqe As IBM.WMQ.MQException
                    '* report the error
                    System.Console.WriteLine("MQQueue::Put ended with {0}", mqe.Message)
                End Try
            Else
                '* quit loop when empty line is read
                isContinue = False
            End If
        Loop

        System.Console.WriteLine("Sample VMQSPUT end")
        Return (0)

    End Function

End Module
